#!/usr/bin/environ python
#
# dataclass_wizard documentation build configuration file, created by
# sphinx-quickstart on Fri Jun  9 13:47:02 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another
# directory, add these directories to sys.path here. If the directory is
# relative to the documentation root, use os.path.abspath to make it
# absolute, like shown here.
#
import os
import sys

# Insert the Project root path into the system.
sys.path.insert(0, os.path.abspath('..'))

from dataclass_wizard import __version__

# -- General configuration ---------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.viewcode',
    'sphinx_issues',
    'sphinx_autodoc_typehints',
    'sphinx_copybutton',
]

copybutton_exclude = '.linenos, .gp, .go'

autodoc_typehints = "description"

github_user = 'rnag'
github_repo = 'dataclass-wizard'

# Path to GitHub repo {user}/{project}
issues_github_path = f'{github_user}/{github_repo}'

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = 'Dataclass Wizard'
author = "Ritvik Nag"
copyright = f'2021-2025, <a href="https://github.com/{github_user}">{author}</a>'

# The version info for the project you're documenting, acts as replacement
# for |version| and |release|, also used in various other places throughout
# the built documents.
#
# The short X.Y version.
version = __version__.__version__
# The full version, including alpha/beta/rc tags.
release = __version__.__version__

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = 'en'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Options for HTML output -------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'alabaster'

# Theme options are theme-specific and customize the look and feel of a
# theme further.  For a list of options available for each theme, see the
# documentation.
#
html_theme_options = {
    "github_user": github_user,
    "github_repo": github_repo,
    "description": 'A set of simple, yet elegant <i>wizarding</i> tools for '
                   'interacting with the Python <code>dataclasses</code> module.',
    "show_powered_by": False,
    "github_banner": True,
    "show_related": False,
    "note_bg": "#fff9bf",
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_css_files = [
    'custom.css',
    'dark_mode.css',
]

html_js_files = [
    'dark_mode_toggle.js',
]

# Custom sidebar templates, maps document names to template names.
html_sidebars = {
    "index": ["sidebarintro.html", "sourcelink.html", "sidebar_modindex.html", "searchbox.html", "hacks.html"],
    "**": [
        "sidebarintro.html",
        # -- These are Sphinx builtin templates that are rendered by default --
        # See https://www.sphinx-doc.org/en/master/usage/configuration.html#confval-html_sidebars
        "localtoc.html",
        "relations.html",
        "sidebar_modindex.html",  # Except this one, which is a custom template
        "sourcelink.html",
        "searchbox.html",
        # -- End --
        "hacks.html",
    ],
}

# -- Options for HTMLHelp output ---------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'dataclass_wizarddoc'


# -- Options for LaTeX output ------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass
# [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'dataclass_wizard.tex',
     'Dataclass Wizard Documentation',
     author, 'manual'),
]


# -- Options for manual page output ------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'dataclass_wizard',
     'Dataclass Wizard Documentation',
     [author], 1)
]


# -- Options for Texinfo output ----------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'dataclass_wizard',
     'Dataclass Wizard Documentation',
     author,
     'dataclass_wizard',
     'One line description of project.',
     'Miscellaneous'),
]



